@@ -3,7 +3,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::MetaProvides::Package;
 BEGIN {
-  $Dist::Zilla::Plugin::MetaProvides::Package::VERSION = '1.12044908';
+  $Dist::Zilla::Plugin::MetaProvides::Package::VERSION = '1.12060213';
 }
 
 # ABSTRACT: Extract namespaces/version from traditional packages for provides
@@ -27,12 +27,16 @@ has '+meta_noindex' => ( default => sub { 1 } );
 
 sub provides {
   my $self        = shift;
-  my $perl_module = sub { $_->name =~ m{^lib\/.*\.(pm|pod)$} };
+  my $perl_module = sub {
+    ## no critic (RegularExpressions)
+    $_->name =~ m{^lib[/].*[.](pm|pod)$};
+  };
   my $get_records = sub {
     $self->_packages_for( $_->name, $_->content );
   };
-
-  return $self->_apply_meta_noindex( $self->zilla->files->grep($perl_module)->map($get_records)->flatten );
+  my (@files)   = $self->zilla->files()->flatten;
+  my (@records) = @files->grep($perl_module)->map($get_records)->flatten;
+  return $self->_apply_meta_noindex(@records);
 }
 
 
@@ -41,14 +45,14 @@ sub _packages_for {
 
   my ( $fh, $fn );
 
-tempextract: {
+TEMPEXTRACT: {
 
-    $self->log_debug( "Get packages for " . $filename );
+    $self->log_debug( q{Get packages for } . $filename );
     $fh = File::Temp->new( UNLINK => 0, OPEN => 1, SUFFIX => '.pm' );
     $fh->unlink_on_destroy(1);
-    binmode( $fh, ':raw' );
-    print {$fh} $content;
-    close $fh;
+    binmode $fh, ':raw';
+    print {$fh} $content or $self->log_debug(q{print to filehandle failed});
+    close $fh or $self->log_debug(q{closing filehandle failed});
     $fn = $fh->filename;
   }
 
@@ -74,6 +78,7 @@ tempextract: {
 
 
 __PACKAGE__->meta->make_immutable;
+no Moose;
 1;
 
 
@@ -86,7 +91,7 @@ Dist::Zilla::Plugin::MetaProvides::Package - Extract namespaces/version from tra
 
 =head1 VERSION
 
-version 1.12044908
+version 1.12060213
 
 =head1 SYNOPSIS
 
@@ -105,7 +110,7 @@ In your C<dist.ini>:
 
 =head2 L<< C<inherit_version>|Dist::Zilla::Role::MetaProvider::Provider/inherit_version >>
 
-How do you want existing versions ( Versions hardcoded into files before running this plug-in )to be processed?
+How do you want existing versions ( Versions hard-coded into files before running this plug-in )to be processed?
 
 =over 4
 
@@ -159,7 +164,7 @@ eliminate it from the metadata shipped to L<Dist::Zilla>
 
 =head2 provides
 
-A conformant function to the L<Dist::Zila::Role::MetaProvider::Provider> Role.
+A conformant function to the L<Dist::Zilla::Role::MetaProvider::Provider> Role.
 
 =head3 signature: $plugin->provides()
 
@@ -187,7 +192,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Kent Fredric.
+This software is copyright (c) 2011 by Kent Fredric.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
